==> haskell-row-types-1.0.1.2-34-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-FQkLZYizLy6IrD2AIWrDwp
key:                  row-types-1.0.1.2-FQkLZYizLy6IrD2AIWrDwp
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  3791f610d2728f232cf8c47b45ef61b9
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-FQkLZYizLy6IrD2AIWrDwp
depends:
    base-4.17.2.1 constraints-0.14.2-1QQNMMihZvL7jPWzLI9hpf
    deepseq-1.4.8.0 generic-lens-2.2.2.0-DujVROVmCY1DT9F6jNg7On
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    profunctors-5.6.3-7SwpvPUR3WDDKDPlUxhog4 text-2.0.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-row-types-1.0.1.2-56-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-row-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 row-types
version:              1.0.1.2
visibility:           public
id:                   row-types-1.0.1.2-4x8U1r2LNA9AnBIlVe6fUq
key:                  row-types-1.0.1.2-4x8U1r2LNA9AnBIlVe6fUq
license:              MIT
maintainer:           dwincort@gmail.com
author:               Daniel Winograd-Cort, Matthew Farkas-Dyck
homepage:             https://github.com/target/row-types
synopsis:             Open Records and Variants
description:
    This package uses closed type families and type literals to implement open
    records and variants.
    The core is based off of the <https://hackage.haskell.org/package/CTRex CTRex>
    package, but it also includes polymorphic variants and a number of
    additional functions.  That said, it is not a proper superset of CTRex as it
    specifically forbids records from having more than one element of the same
    label.

category:             Data, Data Structures
abi:                  884469a2cb9f669351cf4b8aefd8fb53
exposed:              True
exposed-modules:
    Data.Row Data.Row.Dictionaries Data.Row.Internal Data.Row.Records
    Data.Row.Switch Data.Row.Variants

import-dirs:          /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/row-types-1.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-row-types
hs-libraries:         HSrow-types-1.0.1.2-4x8U1r2LNA9AnBIlVe6fUq
depends:
    base-4.17.2.1 constraints-0.14.2-Fcc8FwY8waN8FnX72pAilZ
    deepseq-1.4.8.0 generic-lens-2.2.2.0-CNtj3yZuEaO5J3CA2ldPnb
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    profunctors-5.6.3-GJws21l5du15P9B6ShOpfs text-2.0.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:   /usr/share/doc/haskell-row-types/html/row-types.haddock
haddock-html:         /usr/share/doc/haskell-row-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
